@@ -2,16 +2,15 @@ package Mojolicious::Plugin::NamedHelpers;
 use Mojo::Base 'Mojolicious::Plugin';
 use Sub::Util qw(set_subname);
 
-our $VERSION = '0.02';
-
+our $VERSION = '0.03';
 
 sub register {
   my ($self, $app, $arg) = @_;
-  my $namespace = $arg->{namespace} // ref($app);
+  $arg->{namespace} //= ref($app);
   $app->helper(
     named_helper => sub {
       my ($c, $name, $sub) = @_;
-      $c->app->helper($name => set_subname "$namespace::$name", $sub);
+      $c->app->helper($name => set_subname "$arg->{namespace}::$name", $sub);
     }
   );
 }
@@ -45,7 +44,7 @@ Without this plugin those subs will be named __ANON__, but now they will be name
 
 By default the namespace will be the same as the app, but this can be overridden if desired.
 
-The author's use-case is for providing more context in JSON-based application logs, where all helpers would identidy themselves as __ANON__.
+The author's use-case is for providing more context in JSON-based application logs, where all helpers would identify themselves as __ANON__.
 
 =head1 HELPERS
 
